@@ -7,10 +7,10 @@ class WaterFrame:
 
     from .analysis import (
         min, max, copy, use_only, rename, corr, max_diff, time_intervals, resample, slice_time,
-        info_metadata, info_vocabulary, drop)
+        info_metadata, info_vocabulary, drop, reduce_memory)
     from .output import to_nc, to_pkl, to_json, to_es, metadata_to_html, to_csv
     from .plot import plot_timeseries, plot_timebar, plot_hist, plot
-    from .qc import qc_flat_test, qc_range_test, qc_spike_test, qc_replace
+    from .qc import qc_flat_test, qc_range_test, qc_spike_test, qc_replace, qc_syntax_test
     from .iplot import (
         iplot_location, iplot_timeseries, iplot, iplot_scatter, iplot_line,
         iplot_data_intervals)
@@ -88,6 +88,16 @@ class WaterFrame:
 
         return message
 
+    def _repr_html_(self, *args, **kwargs):
+        data_html = self.data._repr_html_()
+
+        metadata_list = ''
+        for key, value in self.metadata.items():
+            metadata_list += f'<li><b>{key}</b>: {value}</li>'
+
+        dictionary_html = f'<div><p>Metadata:</p><ul>{metadata_list}</ul><p>Data:</p></div>'
+        return dictionary_html + data_html
+
     @property
     def parameters(self):
         """
